==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/plugin/0ch_BE_HS.pl <==
#============================================================================================================
#
#	g@\ - BE(HS)ۂ
#	0ch_BE_HS.pl
#
#	by 낿˂vX
#	http://zerochplus.sourceforge.jp/
#
#	  O  K  r e a d m e . t x t         B
#	ǂ܂ȂƂȂ͖̒   Q       B
#
#	---------------------------------------------------------------------------
#
#	2010.08.26 start
#
#============================================================================================================
package ZPL_BE_HS;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my $obj={};
	bless($obj,$this);
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	̕
#
#------------------------------------------------------------------------------------------------------------
sub getName
{
	my	$this = shift;
	return 'BE(HS)ۂ';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	
#
#------------------------------------------------------------------------------------------------------------
sub getExplanation
{
	my	$this = shift;
	return 'Q˂BEɃOCł悤ɂ܂';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\^Cv擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	g@\^Cv(X:1,X:2,read:4,index:8)
#
#------------------------------------------------------------------------------------------------------------
sub getType
{
	my	$this = shift;
	return (1 | 2);
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\sC^tFCX
#	-------------------------------------------------------------------------------------
#	@param	$sys	MELKOR
#	@param	$form	SAMWISE
#	@return	Ȉꍇ0
#
#------------------------------------------------------------------------------------------------------------
sub execute
{
	use strict;
	use warnings;
	my $this = shift;
	my ($sys, $form, $type) = @_;
	
	#--------------------------------------------------------------------------------------------------------
	#	[U[ݒ荀
	#	---------------------------------------------------------------------------------
	#	ڂreadme.txt
	#--------------------------------------------------------------------------------------------------------
	
	# sssp://(BEACR\)LɂH(1:L,0:)
	my $be_icon = 0;
	
	
	# O擾
	my $name = $form->Get('FROM');
	
	# {擾
	my $mes  = $form->Get('MESSAGE');
	
	# ΍łƂ肠ɂ
	$form->Set('BEID', '');
	$form->Set('BERANK', '0');
	
	if ( $name =~ /!BE.+!HS/ ) {
		
		my ( $beid, $key );
		
		if ( $name =~ /!BE(\d+)!HS.*?#(.+)$/ ) {
			$beid = $1;
			$key = $2;
		}
		elsif ( $name =~ /!BE(\d+)-#(.+)!HS/ ) {
			$beid = $1;
			$key = $2;
		}
		
		my ($CONV, $SET, $trip, $key2, $column, @ct_arg);
		if (defined $sys->{'MainCGI'}) {
			$CONV = $sys->{'MainCGI'}->{'CONV'};
			$SET = $sys->{'MainCGI'}->{'SET'};
			$column = $SET->Get('BBS_TRIPCOLUMN');
			$trip = $CONV->ConvertTrip(\$key, $column, $sys->Get('TRIP12'));
		}
		else {
			require './module/galadriel.pl';
			$CONV = GALADRIEL->new;
			require './module/isildur.pl';
			$SET = ISILDUR->new;
			$SET->Load($sys);
			$column = $SET->Get('BBS_TRIPCOLUMN');
			$key = "#$key";
			$CONV->ConvertTrip(\$key, $column);
			$key =~ m|([A-Za-z0-9\.]+)|;
			$trip = $1;
		}
		
		# Ƃ肠
		$name =~ s/!BE.+!HS//;
		if ($form->IsExist('TRIPKEY') && $name =~ /#(.+)$/) {
			$key2 = $1;
			$ct_arg[0] = \$key2;
			$key2 = $CONV->ConvertTrip(\$key2, $column, $sys->Get('TRIP12'));
			$form->Set('TRIPKEY', $key2);
		}
		
		$form->Set('FROM', $name);
		
		# BEvtURLłˁI
		my $beprof = "http://be.2ch.net/test/p.php?i=$beid";
		
		# LWP̐ݒ
		my ( $code, $content ) = BeGet($beprof);
		
		# HTML
		if ( $code ne 200 ) {
			$form->Set('BEID', "BE:擾G[($code)");
			return 0;
		}
		
		# Shift_JISc
		require Encode;
		Encode::from_to( $content, 'EUC-JP', 'Shift_JIS' );
		
		if ( $content =~ /<div id="sitename">\n<h1>(.+)<\/h1>/ ) {
			
			my $name = $1;
			$name =~ s|^.*([A-Za-z0-9\./]{10,12}).*$|$1|;
			
			# ̓gbvƃvt̃gbv̈v𒲂ׂ
			if ( $trip eq $name ) {
				
				my $point = 0;
				
				# |Cg擾
				if ( $content =~ m/<p><b>be.{8}<\/b>:([0-9]+)<\/p>/ ) {
					$point = BeRank($form, $1);
				}
				else {
					# ݂ȂO|Cg
					$point = '2BP(0)';
				}
				
				$form->Set('BEID', "BE:$beid-$point");
				
				# ACRƂĂI
				if ( $be_icon ) {
					
					# sssp://http://ɕϊ
					$mes =~ s|sssp://|http://|gi;
					
					if ( $content =~ m|<img src="http://img.2ch.net/(.+)" />\n\n|i ) {
						my $sssp = "sssp://img.2ch.net/$1";
						$mes = "$sssp<br>$mes";
					}
					
					$form->Set('MESSAGE', "$mes");
					
				}
				
			}
			else {
				#$form->Set('BEID', "BE:F؃G[($trip:$name)");
				return 0;
			}
			
		}
		else {
			$form->Set('BEID', '擾G[(-1)');
			return 0;
		}
		
	}
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	gbv쐬֐
#	-------------------------------------------------------------------------------------
#	@param	$key	gbvL[
#	@return	$trip	gbv
#
#------------------------------------------------------------------------------------------------------------
sub ConvertTrip1
{
	
	my ( $key ) = @_;
	
	# ]̃gbv
	my $salt = substr($key . 'H.', 1, 2);
	$salt =~ s/[^\.-z]/\./go;
	$salt =~ tr/:;<=>?@[\\]^_`/ABCDEFGabcdef/;
	
	# 0x80Č
	$key =~ s/\x80[\x00-\xff]*$//;
	
	my $trip = substr(crypt($key, $salt), -10);
	
	return $trip;
	
}

#------------------------------------------------------------------------------------------------------------
#
#	BEvtB[y[W擾
#	-------------------------------------------------------------------------------------
#	@param	$url	BEvt
#	@return	$code	HTTPXe[^X
#	@return $cont	BevtHTML
#
#------------------------------------------------------------------------------------------------------------
sub BeGet {
	
	my ( $url ) = @_;
	
	require LWP::UserAgent;
	my $ua   = new LWP::UserAgent;
	$ua->agent('Mozilla/5.0 (Windows; U; Windows NT 5.1; ja; rv:1.9.2.8) Gecko/20100722 Firefox/3.6.8');
	$ua->timeout(5);
	
	# ƂĂ
	my $req  = HTTP::Request->new(GET => $url);
	my $res  = $ua->request($req);
	my $cont = $res->content;
	my $code = $res->code;
	
	return ( $code, $cont );
	

}
#------------------------------------------------------------------------------------------------------------
#
#	BEN擾
#	-------------------------------------------------------------------------------------
#	@param	$form	$form
#	@param	$point	|Cg
#	@return	N\` 2BP(0)
#
#------------------------------------------------------------------------------------------------------------
sub BeRank {
	
	my ( $form, $point ) = @_;
	
	if ( $point < 10000 ) {
		$point = "2BP($point)";
		$form->Set('BERANK', 1);
	}
	elsif ( $point < 12000 ) {
		$point = "BRZ($point)";
		$form->Set('BERANK', 2);
	}
	elsif ( $point < 100000 ) {
		$point = "PLT($point)";
		$form->Set('BERANK', 3);
	}
	elsif ( $point < 500000 ) {
		$point = "DIA($point)";
		$form->Set('BERANK', 4);
	}
	elsif ( $point >= 500000 ) {
		$point = "S($point)";
		$form->Set('BERANK', 5);
	}
	else {
		$point = "2BP(0)";
		$form->Set('BERANK', 1);
	}
	
	return $point;
	
}


#============================================================================================================
#	Module END
#============================================================================================================
1;
__END__

==> zerochplus_0.7.2.tar.gz: zerochplus_0.7.2/test/plugin/0ch_BE_HS.pl <==
#============================================================================================================
#
#	g@\ - BE(HS)ۂ
#	0ch_BE_HS.pl
#
#	by 낿˂vX
#	http://zerochplus.sourceforge.jp/
#
#	  O  K  r e a d m e . t x t         B
#	ǂ܂ȂƂȂ͖̒   Q       B
#
#	---------------------------------------------------------------------------
#
#	2010.08.26 start
#
#============================================================================================================
package ZPL_BE_HS;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my $obj={};
	bless($obj,$this);
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\̎擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	̕
#
#------------------------------------------------------------------------------------------------------------
sub getName
{
	my	$this = shift;
	return 'BE(HS)ۂ';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	
#
#------------------------------------------------------------------------------------------------------------
sub getExplanation
{
	my	$this = shift;
	return 'Q˂BEɃOCł悤ɂ܂';
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\^Cv擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	g@\^Cv(X:1,X:2,read:4,index:8)
#
#------------------------------------------------------------------------------------------------------------
sub getType
{
	my	$this = shift;
	return (1 | 2);
}

#------------------------------------------------------------------------------------------------------------
#
#	g@\sC^tFCX
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@return	Ȉꍇ0
#
#------------------------------------------------------------------------------------------------------------
sub execute
{
	use strict;
	use warnings;
	my $this = shift;
	my ($Sys, $Form, $type) = @_;
	
	#--------------------------------------------------------------------------------------------------------
	#	[U[ݒ荀
	#	---------------------------------------------------------------------------------
	#	ڂreadme.txt
	#--------------------------------------------------------------------------------------------------------
	
	# sssp://(BEACR\)LɂH(1:L,0:)
	my $be_icon = 0;
	
	
	# O擾
	my $name = $Form->Get('FROM');
	
	# ΍łƂ肠ɂ
	$Form->Set('BEID', '');
	$Form->Set('BEBASE', '0');
	$Form->Set('BERANK', '0');
	
	if ( $name =~ /!BE.+!HS/ ) {
		
		my ( $beid, $key );
		
		if ( $name =~ /!BE(\d+)!HS.*?#(.+)$/ ) {
			$beid = $1;
			$key = $2;
		}
		elsif ( $name =~ /!BE(\d+)-#(.+)!HS/ ) {
			$beid = $1;
			$key = $2;
		}
		
		my ($Conv, $Set, $trip, $key2, $column, @ct_arg, $CGI);
		$CGI = $Sys->Get('MainCGI');
		if (defined $CGI) {
			$Conv = $CGI->{'CONV'};
			$Set = $CGI->{'SET'};
			$column = $Set->Get('BBS_TRIPCOLUMN');
			$trip = $Conv->ConvertTrip(\$key, $column, $Sys->Get('TRIP12'));
		}
		else {
			require './module/galadriel.pl';
			$Conv = GALADRIEL->new;
			require './module/isildur.pl';
			$Set = ISILDUR->new;
			$Set->Load($Sys);
			$column = $Set->Get('BBS_TRIPCOLUMN');
			$key = "#$key";
			$Conv->ConvertTrip(\$key, $column);
			$key =~ m|([A-Za-z0-9\.]+)|;
			$trip = $1;
		}
		
		# Ƃ肠
		$name =~ s/!BE.+!HS//;
		if ($Form->IsExist('TRIPKEY') && $name =~ /#(.+)$/) {
			$key2 = $1;
			$ct_arg[0] = \$key2;
			$key2 = $Conv->ConvertTrip(\$key2, $column, $Sys->Get('TRIP12'));
			$Form->Set('TRIPKEY', $key2);
		}
		
		$Form->Set('FROM', $name);
		
		# BEvtURLłˁI
		my $beprof = "http://be.2ch.net/test/p.php?i=$beid";
		
		# LWP̐ݒ
		my ( $code, $content ) = BeGet($beprof);
		
		# HTML
		if ( $code ne 200 ) {
			#$Form->Set('BEID', "BE:擾G[($code)");
			$Sys->Set('CODE', $code);
			PrintBBSError( $Sys, $Form, 891 );
			return 0;
		}
		
		# Shift_JISc
		require Encode;
		Encode::from_to( $content, 'EUC-JP', 'Shift_JIS' );
		
		if ( $content =~ /<div id="sitename">\n<h1>(.+)<\/h1>/ ) {
			
			my $name = $1;
			$name =~ s|^.*([A-Za-z0-9\./]{10,12}).*$|$1|;
			
			# ̓gbvƃvt̃gbv̈v𒲂ׂ
			if ( $trip eq $name ) {
				
				my $point = 0;
				
				# |Cg擾
				if ( $content =~ m/<p><b>be.{8}<\/b>:([0-9]+)<\/p>/ ) {
					$point = BeRank($Form, $1);
				}
				else {
					# ݂ȂO|Cg
					$point = '2BP(0)';
				}
				
				# bBEԍ擾+Zbg
				$Form->Set('BEBASE', ID2BASE($beid) );
				
				# BE|CgZbg
				$Form->Set('BEID', "BE:$beid-$point");
				
				# ACRƂĂI
				if ( $be_icon && $Form->Get('MESSAGE') ne "" ) {
					
					if ( $content =~ m|<img .+ alt="icon:([^\"]+)" />\n\n|i ) {
						$Form->Set('MESSAGE', "sssp://img.2ch.net/ico/$1<br>".$Form->Get('MESSAGE'));
					}
					
				}
				
			}
			else {
				#$Form->Set('BEID', "BE:F؃G[($trip:$name)");
				$Sys->Set('CHK', "".$trip);
				PrintBBSError( $Sys, $Form, 892 );
				return 0;
			}
			
		}
		else {
			#$Form->Set('BEID', '擾G[(-1)');
			PrintBBSError( $Sys, $Form, 890 );
			return 0;
		}
		
	}
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	BEvtB[y[W擾
#	-------------------------------------------------------------------------------------
#	@param	$url	BEvt
#	@return	$code	HTTPXe[^X
#	@return $cont	BevtHTML
#
#------------------------------------------------------------------------------------------------------------
sub BeGet
{
	
	my ( $url ) = @_;
	
	require('./module/httpservice.pl');
	
	my $proxy = HTTPSERVICE->new;
	$proxy->setURI($url);
	$proxy->setAgent('Mozilla/5.0 Plugin for 0ch+; 0ch_BE_HS.pl http://zerochplus.sourceforge.jp/');
	$proxy->setTimeout(3);
	
	# ƂĂ
	$proxy->request();
	
	my $cont = $proxy->getContent();
	my $code = $proxy->getStatus();
	
	return ( $code, $cont );
	

}
#------------------------------------------------------------------------------------------------------------
#
#	BEN擾
#	-------------------------------------------------------------------------------------
#	@param	$Form	$Form
#	@param	$point	|Cg
#	@return	N\` 2BP(0)
#
#------------------------------------------------------------------------------------------------------------
sub BeRank
{
	
	my ( $Form, $point ) = @_;
	
	if ( $point < 10000 ) {
		$point = "2BP($point)";
		$Form->Set('BERANK', 1);
	}
	elsif ( $point < 12000 ) {
		$point = "BRZ($point)";
		$Form->Set('BERANK', 2);
	}
	elsif ( $point < 100000 ) {
		$point = "PLT($point)";
		$Form->Set('BERANK', 3);
	}
	elsif ( $point < 500000 ) {
		$point = "DIA($point)";
		$Form->Set('BERANK', 4);
	}
	elsif ( $point >= 500000 ) {
		$point = "S($point)";
		$Form->Set('BERANK', 5);
	}
	else {
		$point = "2BP(0)";
		$Form->Set('BERANK', 1);
	}
	
	return $point;
	
}

#------------------------------------------------------------------------------------------------------------
#
#	BEID->bBEԍ擾
#	-------------------------------------------------------------------------------------
#	@param	$id		BEID
#	@return	bBEԍ
#
#------------------------------------------------------------------------------------------------------------
sub ID2BASE
{
	
	my ($id) = @_;
	my ($base, $a, $b, $c, $d);
	
	$base = 0;
	
	if (($b = $id % 10) && ($a = ($id % 100 - $b) / 10) &&
		! (($c = ($id - $id % 100) / 100 + $a - $b - 5) % ($d = $a * $b * 3))) {
		$base = $c / $d;
	}
	
	return $base;
	
}

#------------------------------------------------------------------------------------------------------------
#
#	bBEԍ->BEID擾
#	-------------------------------------------------------------------------------------
#	@param	$base	bBEԍ
#	@return	BEIDz
#
#------------------------------------------------------------------------------------------------------------
sub BASE2ID
{
	
	my ($base) = @_;
	my @id = ();
	
	for my $a (1 .. 9) {
		for my $b (1 .. 9) {
			push @id, ($base * $a * $b * 3 - $a + $b + 5) * 100 + $a * 10 + $b;
		}
	}
	
	return sort { $a <=> $b } @id;
	
}

#------------------------------------------------------------------------------------------------------------
#
#	Ȃ񂿂bbs.cgiG[y[W\
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@param	$err	G[ԍ
#	@return	Ȃ
#	exit	G[ԍ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBBSError
{
	my ($Sys,$Form,$err) = @_;
	my $CGI;
	
	require('./module/radagast.pl');
	require('./module/isildur.pl');
	require('./module/thorin.pl');
	
	$CGI->{'SYS'}		= $Sys;
	$CGI->{'FORM'}		= $Form;
	$CGI->{'COOKIE'}	= RADAGAST->new;
	$CGI->{'COOKIE'}->Init();
	$CGI->{'SET'}		= ISILDUR->new;
	$CGI->{'SET'}->Load($Sys);
	my $Page = THORIN->new;
	
	require('./module/orald.pl');
	$ERROR = ORALD->new;
	$ERROR->Load($Sys);
	
	$ERROR->Print($CGI,$Page,$err,$Sys->Get('AGENT'));
	
	$Page->Flush('',0,0);
	
	exit($err);
}

#============================================================================================================
#	Module END
#============================================================================================================
1;
__END__
=pod
# 890` BEVXeG[n
890<>Be擾s<>Be[U[̎擾Ɏs܂B
890<>BeOCs<>BeOCɎs܂B
891<>BeOCK{<><a href="http://be.2ch.net/">be.2ch.net</a>ŃOCĂȂƏ܂B
892<>BE_TYPE2K<>BeOCĂ(t)B<a href="http://be.2ch.net/">be.2ch.net</a>
=cut
